DigitalOutput

Struct DigitalOutput 

pub struct DigitalOutput { /* private fields */ }
Represents a digital actuator of unspecified type: an Output Device that write digital values from an OUTPUT compatible pin. https://docs.arduino.cc/language-reference/en/functions/digital-io/digitalwrite/

Implementations

Source

impl DigitalOutput

pub fn new<T: Into<PinIdOrName>>( board: &dyn Hardware, pin: T, default: bool, ) -> Result<Self, Error>

Creates an instance of a DigitalOutput attached to a given board.

Errors
  • HardwareError::UnknownPin: this function will bail an error if the pin does not exist for this board.
  • HardwareError::IncompatiblePin: this function will bail an error if the pin does not support OUTPUT mode.
pub fn turn_on(&mut self) -> Result<&Self, Error>

Turn the output HIGH.

pub fn turn_off(&mut self) -> Result<&Self, Error>

Turn the output LOW.

pub fn toggle(&mut self) -> Result<&Self, Error>

Toggle the current state, if on then turn off, if off then turn on.

pub fn get_pin(&self) -> u8

Returns the pin (id) used by the device.

pub fn get_pin_info(&self) -> Result<Pin, Error>

Returns Pin information.

pub fn is_high(&self) -> bool

Indicates if the device state is HIGH.

pub fn is_low(&self) -> bool

Indicates if the device state is LOW.