pub struct PwmOutput { /* private fields */ }Expand description
Represents an analog actuator of unspecified type: an Output Device that write analog values from a PWM compatible pin.
https://docs.arduino.cc/language-reference/en/functions/analog-io/analogWrite/
Implementations
Sourceimpl PwmOutput
impl PwmOutput
Sourcepub fn new<T: Into<PinIdOrName>>(
board: &dyn Hardware,
pin: T,
default: u16,
) -> Result<Self, Error>
pub fn new<T: Into<PinIdOrName>>( board: &dyn Hardware, pin: T, default: u16, ) -> Result<Self, Error>
Sourcepub fn set_percentage(&mut self, percentage: u8) -> Result<&Self, Error>
pub fn set_percentage(&mut self, percentage: u8) -> Result<&Self, Error>
Sets the PWM value to a percentage of its max value. NOTE: everything above 100 is considered 100%.
Sourcepub fn get_percentage(&self) -> u8
pub fn get_percentage(&self) -> u8
Gets the current percentage of the PWM value compared to max possible.