Input

Trait Input 

pub trait Input: Device {
    // Required method
    fn get_state(&self) -> State;
}
A trait for devices that can sense or measure data: they “input” some data into the board.

This trait extends Device and is intended for sensors that require the same capabilities as devices, including debugging, cloning, and concurrency support.

Required Methods

fn get_state(&self) -> State

Returns the sensor current state.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors