pub struct DigitalOutput { /* private fields */ }Expand description
Represents a digital actuator of unspecified type: an Output Device that write digital values
from an OUTPUT compatible pin.
https://docs.arduino.cc/language-reference/en/functions/digital-io/digitalwrite/
Implementations
Sourceimpl DigitalOutput
impl DigitalOutput
Sourcepub fn new<T: Into<PinIdOrName>>(
board: &dyn Hardware,
pin: T,
default: bool,
) -> Result<Self, Error>
pub fn new<T: Into<PinIdOrName>>( board: &dyn Hardware, pin: T, default: bool, ) -> Result<Self, Error>
Creates an instance of a DigitalOutput attached to a given board.
Errors
HardwareError::UnknownPin: this function will bail an error if the pin does not exist for this board.HardwareError::IncompatiblePin: this function will bail an error if the pin does not support OUTPUT mode.