pub trait Device:
Debug
+ Display
+ DynClone
+ Send
+ Sync { }Expand description
A trait for devices that can be debugged, cloned, and used in concurrent contexts.
Device are one of the entities defined in Hermes-Five project: it represents a physical
device that is plugged to and can be controlled by a Board. Devices come in two flavor:
Actuator: device that can act on the worldSensor: device that can sense or measure data from the world
Implementors of this trait are required to be Debug, DynClone, Send, and Sync.
This ensures that devices can be cloned and used safely in multithreaded and async environments.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".