pub trait Input: Device {
// Required method
fn get_state(&self) -> State;
}Expand description
A trait for devices that can sense or measure data: they “input” some data into the board.
This trait extends Device and is intended for sensors that require the same capabilities
as devices, including debugging, cloning, and concurrency support.